//
//  BaiduOAuth.h
//  OAuth
//
//  Created by Gang,Liu on 2018/12/26.
//  Copyright © 2018年 Gang,Liu. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

/**
 OAuth SDK 本地错误码
 */
typedef NS_ENUM(NSInteger, BDOAuthErrorCode) {
    BDOAErrorCodeSucceed = 0,                //成功
    BDOAErrorCodeUnknowError = -201,         //其他错误
    BDOAErrorCodeParamsInvalid = -202,       //参数错误
    BDOAErrorCodeNetworkException = -203,    //网络异常
    BDOAErrorCodeResponseInvalid = -204,     //服务返回的异常
    BDOAErrorCodeUserCancel = -205,          //用户取消
    BDOAErrorCodeInitFail = -206,            //SDK未初始化、初始化失败
    BDOAErrorCodeNotInstallBaidu = -207,     //没有安装百度系app，扫码oauth必须安装
    BDOAErrorCodeLowVersion = -208           //百度app版本号太低，需要升级
};

/**
OAuth 授权方式
*/
typedef NS_ENUM(NSInteger, BDOAuthType) {
    BDOAuthTypeDefault = 0,  //若安装百度系app调起SSO授权，否则调起Web授权
    BDOAuthTypeSSO,          //若安装百度系app调起调起SSO授权，否则报错
    BDOAuthTypeWeb           //调起Web授权
};

@interface BDOAuthConfig : NSObject
/**
OAuth 授权方式
*/
@property (nonatomic, assign) BDOAuthType oauthType;
/**
 重定向后会携带state参数
*/
@property (nonatomic, copy) NSString *state;
@end

@interface BDOAuthResponse : NSObject

/**
 code 开发者拿到code后，通过服务端换取token，code过期时间10分钟
 */
@property (nonatomic, copy) NSString *code;

/**
 调起授权前传入的state参数
*/
@property (nonatomic, copy) NSString *state;

- (instancetype)initWithDictionary:(NSDictionary *)responseInfo;

- (NSDictionary *)toDictionary;

- (BOOL)isValid;

@end

@protocol BaiduOAuthDelegate <NSObject>

/**
 授权成功回调
 */
- (void)didReceiveBaiduResponse:(BDOAuthResponse *)response;

/**
 授权失败回调
 */
- (void)didReceiveBaiduError:(NSError *)error;

@end

@interface BaiduOAuth : NSObject

/**
 初始化SDK

 @param apiKey      :应用的API Key
 @param appId       :应用的APP ID
 @param scope       :需要授予的权限列表，','分割
 @param redirectURI :开发者服务器地址
 @param delegate    :接收授权事件回调的代理，需准守实现 BaiduOAuthDelegate 代理方法
 */
+ (BOOL)registerApikey:(NSString *)apiKey appId:(NSString *)appId scope:(NSString *)scope redirectURI:(NSString *)redirectURI delegate:(id<BaiduOAuthDelegate>)delegate;

/**
 发起授权，调起百度系app，若未安装百度系app会打开web授权登录页面
 */
+ (BOOL)sendRequest;

/**
 根据指定type调起授权
 */
+ (BOOL)sendRequestWithConfig:(BDOAuthConfig *)config;

/**
 判断是否为百度系客户端SSO回调
 */
+ (BOOL)canHandleOpenURL:(NSURL *)url;

/**
 处理百度系客户端SSO时调起的操作
 */
+ (BOOL)handleOpenURL:(NSURL *)url;

/**
 是否能处理二维码内容
 
 @param content 二维码内容
 @return 能处理时返回YES，其他情况返回NO
 */
+ (BOOL)canRequestWithQrcodeContent:(NSString *)content;


/*处理二维码内容，跳转授权

@param content 二维码内容
*/
+ (void)requestWithQrcodeContent:(NSString *)content;

/*处理二维码内容，跳转授权

@param content 二维码内容
@param config  根据指定type调起授权
*/
+ (void)requestWithQrcodeContent:(NSString *)content config:(BDOAuthConfig *)config;

/**
 SDK版本号

 @return 版本号，如：1.0.0
 */
+ (NSString *)sdkVersion;

@end

NS_ASSUME_NONNULL_END
